from setuptools import setup

setup(name='easy_shortcut',
      version='0.0',
      description='Easy make shortcut',
      packages=['easy_shortcut'],
      author_email='foton-pc@inbox.ru',
      zip_safe=False,
      install_requires=['pywin32','winshell'])
